@@ -17,6 +17,9 @@ def main(
     ),
     port: Optional[int] = typer.Option(8000, help="Port to run lof"),
     host: Optional[str] = typer.Option("0.0.0.0", help="Host to run lof"),
+    proxy_lambdas: Optional[str] = typer.Option(
+        "", 
+        help="Lambdas Names that must be used as Handlers for request. For example, Authorizer Lambda or CORS Lambds. Each time when you send request to some lambda - it will go through those lambdas and populate 'requestContext' in the event"), 
     workers: Optional[int] = typer.Option(
         1,
         help="Count of unicorn workers to run."
@@ -25,16 +28,19 @@ def main(
     debug: Optional[bool] = typer.Option(True, help="Debug flag for Uvicorn"),
     reload: Optional[bool] = typer.Option(False, help="Reload flag for Uvicorn"),
 ):
-
+    exclude = [i.strip() for i in exclude.split(",")]
+    proxy_lambdas = [i.strip() for i in proxy_lambdas.split(",")]
+    
     runner(
         template_file=template,
         variables_file=env,
-        exclude=exclude.split(","),
+        exclude=exclude,
         port=port,
         host=host,
         workers=workers,
         debug=debug,
         reload=reload,
+        proxy_lambdas=proxy_lambdas
     )
 
 
