@@ -11,8 +11,7 @@ route_template = """
 async def {function_name}(request: Request, response: Response):
     my_module = importlib.import_module("{module}")
     _handler = getattr(my_module, "{handler}")
-    event = await prepare_api_gateway_event(request)
-    result = _handler(event, {{}})
+    result = _handler(app.event, {{}})
     status_code = result.get("statusCode") or result.get("status_code") or 200
     if result.get("body"):
         content = result.get("body")
@@ -29,7 +28,6 @@ async def {function_name}(request: Request, response: Response):
     return response
 """
 
-
 def create_temp_app_folder() -> str:
     lof_path = os.path.join(os.getcwd(), LOF_DIR)
     os.makedirs(lof_path, exist_ok=True)
@@ -40,7 +38,10 @@ def create_temp_app_folder() -> str:
 
 
 def get_function_name(method: str, endpoint: str) -> str:
-    return f"{method}_{endpoint.split('{')[0].replace('/', '_')}"
+    endpoint_name = endpoint.split("{")[0]
+    for symbol in ["/", "-", "&", "$", "%"]:
+        endpoint_name = endpoint_name.replace(symbol, "_")
+    return f"{method}_{endpoint_name}"
 
 
 def create_route(endpoint: str, method: str, handler: str):
@@ -71,13 +72,13 @@ def get_routes(lambdas: List[Dict]) -> List[str]:
     return routes
 
 
-def render_app_template(lambdas: List[Dict]) -> str:
+def render_app_template(lambdas: List[Dict], proxy_lambdas: List[Dict]) -> str:
     current_dir = os.path.dirname(os.path.abspath(__file__))
     template_path = os.path.join(current_dir, "template.jinja2")
     with open(template_path) as file_:
         template = Template(file_.read())
     app_routes = get_routes(lambdas)
-    app_code = template.render({"routes": app_routes})
+    app_code = template.render({"routes": app_routes, "proxy_lambdas": proxy_lambdas})
     return app_code
 
 
@@ -86,6 +87,6 @@ def save_app_code(app_code, lof_dir) -> None:
         main_module.write(app_code)
 
 
-def generate_app(lambdas: List[Dict], lof_dir: str) -> str:
-    app_code = render_app_template(lambdas)
+def generate_app(lambdas: List[Dict], lof_dir: str, proxy_lambdas: List[Dict]) -> str:
+    app_code = render_app_template(lambdas, proxy_lambdas)
     save_app_code(app_code, lof_dir)
